### Installation

This one package will let you use `Bootstrap v3` *(with all css components, js plugins and glyphicons provided by bootstrap)* in your project.
Use `npm install webpack-bootstrap-installer` instead of installing all dependencies and loaders separately.

The following dependencies will be installed:

| Package name |
|:-------------:|
| bootstrap |
| jquery |
| css-loader |
| style-loader |
| file-loader |
| url-loader |
| webpack |

### Configuration

##### 1. Set globals

Use the `ProvidePlugin` in the `plugins` object of `webpack.config.js` file to inject `jquery` implicit globals:

```javascript
plugins: [
  new webpack.ProvidePlugin({
    $: "jquery",
    jQuery: "jquery",
    "window.jQuery": "jquery'",
    "window.$": "jquery"
]
```


##### 2. Set loaders
Add the loaders to your `webpack.config.js` file

```javascript
module: {
  loaders: [
    {test: /\.woff(2)?(\?v=[0-9]\.[0-9]\.[0-9])?$/,loader: "url-loader"},
    {test: /\.(ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/,loader: "file-loader"},
    {test: /\.css$/,loader: "style-loader!css-loader"}
  ]
}
```

### Usage

To load `Bootstrap` use

```javascript
require('webpack-bootstrap-installer');
```

or set the entry property in the `webpack.config.js` file:

```javascript
entry: [
  "webpack-bootstrap-installer",
  "your-entry-point"
]
```

Whole `webpack.config.js` file should look like

```javascript
module.exports = {
  entry: [
    "webpack-bootstrap-installer",
    "your-entry-point"
  ],
  output:{...},
  module: {
    loaders: [
      {test: /\.woff(2)?(\?v=[0-9]\.[0-9]\.[0-9])?$/,loader: "url-loader"},
      {test: /\.(ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/,loader: "file-loader"},
      {test: /\.css$/,loader: "style-loader!css-loader"}
    ]
  },
  plugins: [
    new webpack.ProvidePlugin({
      $: "jquery",
      jQuery: "jquery",
      "window.jQuery": "jquery'",
      "window.$": "jquery"
  ]
}
```